@@ -185,9 +185,13 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
     ) -> Tuple[Optional[Figure], Optional[Array]]:
         """Plot label distributions of multiple compounds on a grid."""
         time = self.get_time()
-        plot_groups = [(time, self.get_label_distribution(compound=compound)) for compound in compounds]
+        plot_groups = [
+            (time, self.get_label_distribution(compound=compound))
+            for compound in compounds
+        ]
         legend_groups = [
-            [f"Pos {i}" for i in range(len(self.model.isotopomers[compound]))] for compound in compounds
+            [f"Pos {i}" for i in range(len(self.model.isotopomers[compound]))]
+            for compound in compounds
         ]
         if ylabels is None and relative:
             ylabels = "Relative concentration"
@@ -239,9 +243,13 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
         """Plot label distributions of all compounds on a grid."""
         time = self.get_time()
         compounds = self.model.isotopomers
-        plot_groups = [(time, self.get_label_distribution(compound=compound)) for compound in compounds]
+        plot_groups = [
+            (time, self.get_label_distribution(compound=compound))
+            for compound in compounds
+        ]
         legend_groups = [
-            [f"Pos {i}" for i in range(len(self.model.isotopomers[compound]))] for compound in compounds
+            [f"Pos {i}" for i in range(len(self.model.isotopomers[compound]))]
+            for compound in compounds
         ]
         if ylabels is None and relative:
             ylabels = "Relative concentration"
