@@ -80,7 +80,9 @@ class Parser:
 
         self.sbml_model = doc.getModel()
         if bool(self.sbml_model.getConversionFactor()):
-            self._raise_or_warn("Conversion factors are currently not supported", NotImplementedError)
+            self._raise_or_warn(
+                "Conversion factors are currently not supported", NotImplementedError
+            )
 
         # Collections
         self.produced_compounds: set[str] = set()
@@ -122,7 +124,9 @@ class Parser:
 
     def parse_events(self) -> None:
         if len(self.sbml_model.getListOfEvents()) > 0:
-            self._raise_or_warn("modelbase does not currently support events.", NotImplementedError)
+            self._raise_or_warn(
+                "modelbase does not currently support events.", NotImplementedError
+            )
 
     def parse_units(self) -> None:
         for unit_definition in self.sbml_model.getListOfUnitDefinitions():
@@ -188,7 +192,9 @@ class Parser:
     def parse_species(self) -> None:
         for compound in self.sbml_model.getListOfSpecies():
             if bool(compound.getConversionFactor()):
-                self._raise_or_warn("Conversion factors are not supported", NotImplementedError)
+                self._raise_or_warn(
+                    "Conversion factors are not supported", NotImplementedError
+                )
             compound_id = compound.getId()
             initial_amount = compound.getInitialAmount()
             if str(initial_amount) == "nan":
@@ -327,7 +333,9 @@ class Parser:
             else:
                 raise ValueError("Unknown rate type")
 
-    def _parse_local_parameters(self, reaction_id: str, kinetic_law: libsbml.KineticLaw) -> Dict[str, str]:
+    def _parse_local_parameters(
+        self, reaction_id: str, kinetic_law: libsbml.KineticLaw
+    ) -> Dict[str, str]:
         """Parse local parameters"""
         parameters_to_update = {}
         for parameter in kinetic_law.getListOfLocalParameters():
@@ -365,7 +373,9 @@ class Parser:
             kinetic_law = reaction.getKineticLaw()
             if kinetic_law is None:
                 continue
-            parameters_to_update = self._parse_local_parameters(reaction_id=sbml_id, kinetic_law=kinetic_law)
+            parameters_to_update = self._parse_local_parameters(
+                reaction_id=sbml_id, kinetic_law=kinetic_law
+            )
 
             node = reaction.getKineticLaw().getMath()
             sbml_math = libsbml.formulaToL3String(node)
@@ -390,7 +400,9 @@ class Parser:
                 if species not in self.boundary_species:
                     stoichiometry = substrate.getStoichiometry()
                     if str(stoichiometry) == "nan":
-                        self._raise_or_warn("Cannot parse stoichiometry", NotImplementedError)
+                        self._raise_or_warn(
+                            "Cannot parse stoichiometry", NotImplementedError
+                        )
                     parsed_reactants[species] -= stoichiometry
             parsed_products: defaultdict[str, int] = defaultdict(int)
             for product in reaction.getListOfProducts():
@@ -398,7 +410,9 @@ class Parser:
                 if species not in self.boundary_species:
                     stoichiometry = product.getStoichiometry()
                     if str(stoichiometry) == "nan":
-                        self._raise_or_warn("Cannot parse stoichiometry", NotImplementedError)
+                        self._raise_or_warn(
+                            "Cannot parse stoichiometry", NotImplementedError
+                        )
                     parsed_products[species] += stoichiometry
 
             self.parsed_reactions[sbml_id] = Reaction(
@@ -529,11 +543,17 @@ class Parser:
         explained_args = self.produced_compounds | set(self.converted_constants)
         unexplained_args = list(set(parsed_args).difference(explained_args))
         if len(unexplained_args) > 1:
-            unexplained_args = list(set(unexplained_args).difference(self.consumed_compounds))
+            unexplained_args = list(
+                set(unexplained_args).difference(self.consumed_compounds)
+            )
             if len(unexplained_args) > 1:
-                self._raise_or_warn("No handling for underdetermined eq", NotImplementedError)
+                self._raise_or_warn(
+                    "No handling for underdetermined eq", NotImplementedError
+                )
         elif len(unexplained_args) == 0:
-            self._raise_or_warn("No handling for already determined eq", NotImplementedError)
+            self._raise_or_warn(
+                "No handling for already determined eq", NotImplementedError
+            )
         derived_compound = unexplained_args[0]
         parsed_args.remove(derived_compound)
 
@@ -544,9 +564,13 @@ class Parser:
             eq = sympy.parse_expr(str(rule.function_body))
             function_body = str(sympy.solve(eq, derived_compound)[0])
         except AttributeError:
-            self._raise_or_warn("Equation may not only contain symbols and operators", NotImplementedError)
+            self._raise_or_warn(
+                "Equation may not only contain symbols and operators", NotImplementedError
+            )
         except TypeError:
-            self._raise_or_warn("Equation may not only contain symbols and operators", NotImplementedError)
+            self._raise_or_warn(
+                "Equation may not only contain symbols and operators", NotImplementedError
+            )
 
         sbml_id = rule.sbml_id
         if sbml_id is None or sbml_id == "":
@@ -574,7 +598,9 @@ class Parser:
             parsed_args = rule.parsed_args
             compounds = [i for i in parsed_args if i in self.converted_variables]
             parameters = [i for i in parsed_args if i in self.converted_constants]
-            modifiers = sorted(set(parsed_args).difference(compounds).difference(parameters))
+            modifiers = sorted(
+                set(parsed_args).difference(compounds).difference(parameters)
+            )
             function_args = compounds + modifiers + parameters
 
             self.derived_compounds.add(rule.derived_compound)
@@ -593,7 +619,9 @@ class Parser:
     def _convert_rate_rule_to_reaction(self, rule: RateRule) -> None:
         derived_compound = rule.derived_compound
         if derived_compound in self.parsed_compartments:
-            self._raise_or_warn("Dynamic compartments are unsupported", NotImplementedError)
+            self._raise_or_warn(
+                "Dynamic compartments are unsupported", NotImplementedError
+            )
         parsed_args = rule.parsed_args
         modifiers = rule.modifiers
         if derived_compound in parsed_args:
@@ -679,7 +707,9 @@ class Parser:
 
     def handle_functions(self) -> None:
         for sbml_id, function in self.parsed_functions.items():
-            function.function_body = _simplify_function_body(function_body=function.function_body)
+            function.function_body = _simplify_function_body(
+                function_body=function.function_body
+            )
             self.converted_functions[sbml_id] = function
 
     def _delete_derived_compounds_from_compounds(self) -> None:
@@ -734,10 +764,14 @@ class Parser:
             derived_compound = module.derived_compound
             if "ref" in derived_compound:
                 if derived_compound.rsplit("ref", maxsplit=1)[0] in self.parsed_species:
-                    self._raise_or_warn("Dynamic stoichiometries not supported", NotImplementedError)
+                    self._raise_or_warn(
+                        "Dynamic stoichiometries not supported", NotImplementedError
+                    )
 
             self._set_module_func_args(module=module)
-            module.function_body = _simplify_function_body(function_body=module.function_body)
+            module.function_body = _simplify_function_body(
+                function_body=module.function_body
+            )
         self._sort_assignment_rules()
 
     def _set_reaction_stoichiometries(self, reaction: Reaction) -> None:
@@ -811,7 +845,9 @@ class Parser:
         else:
             compound_args = substrates
 
-        unexplained_args = set(parsed_args).difference(parameters).difference(compound_args)
+        unexplained_args = (
+            set(parsed_args).difference(parameters).difference(compound_args)
+        )
         modifiers_ = sorted(set(modifiers).union(unexplained_args))
         reaction.function_args = compound_args + modifiers_ + parameters
         reaction.parameters = parameters
@@ -821,7 +857,9 @@ class Parser:
         for sbml_id, reaction in self.converted_reactions.items():
             self._set_reaction_stoichiometries(reaction=reaction)
             self._convert_substance_amount_to_concentration(reaction=reaction)
-            reaction.function_body = _simplify_function_body(function_body=reaction.function_body)
+            reaction.function_body = _simplify_function_body(
+                function_body=reaction.function_body
+            )
             self._set_reaction_func_args(reaction=reaction)
 
     def handle_initial_assignments(self) -> None:
@@ -911,7 +949,8 @@ class Parser:
                 )
             except KeyError:
                 self._raise_or_warn(
-                    "Cannot use non-parameter inputs for derived parameter", NotImplementedError
+                    "Cannot use non-parameter inputs for derived parameter",
+                    NotImplementedError,
                 )
 
         # Compounds
@@ -957,13 +996,21 @@ class Parser:
         y0_dict = dict(zip(self.converted_variables, y0))
 
         # Initial assignments
-        possible_sources: Dict[str, Any] = {**model.get_full_concentration_dict(y0), **model.parameters}
+        possible_sources: Dict[str, Any] = {
+            **model.get_full_concentration_dict(y0),
+            **model.parameters,
+        }
         for par_name, assignment in self.converted_initial_assignments.items():
             py_func = self.create_python_function(func=assignment)
             res = py_func(*[possible_sources[k] for k in assignment.function_args])
             if isinstance(res, (list, np.ndarray)):
                 res = res[0]
-            if par_name not in model.compounds and par_name not in model.get_derived_compounds():
-                self._raise_or_warn("Initial assignment targeting unknown type", NotImplementedError)
+            if (
+                par_name not in model.compounds
+                and par_name not in model.get_derived_compounds()
+            ):
+                self._raise_or_warn(
+                    "Initial assignment targeting unknown type", NotImplementedError
+                )
             y0_dict[par_name] = res
         return model, y0_dict
